
# Slot: object


location in which the gene is expressed

URI: [biolink:gene_to_expression_site_association_object](https://w3id.org/biolink/vocab/gene_to_expression_site_association_object)


## Domain and Range

[GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md) &#8594;  <sub>1..1</sub> [AnatomicalEntity](AnatomicalEntity.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [GeneToExpressionSiteAssociation](GeneToExpressionSiteAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Local names:** | | descriptor (ga4gh) |
|  | | node with incoming relationship (neo4j) |
| **Mappings:** | | rdf:object |
| **Examples:** | | Example(value='UBERON:0002037', description='cerebellum') |
| **Exact Mappings:** | | owl:annotatedTarget |
|  | | OBAN:association_has_object |

